@@ -55,7 +55,8 @@ DEFAULTS = {
     'TASK_USE_ON_SUCCESS': False,
     'ELASTICSEARCH_DATABASE': None,
     'ELASTICSEARCH_AUTO_REFRESH': False,
-    'BACKENDS': None,
+    'BACKEND_WRITERS': None,
+    'BACKEND_READER': None,
     'LOG_STRING_IO_FLUSH_TIMEOUT': 5,
 }
 
